==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/Stacked100SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineAreaSeriesDescriptionMetadata } from "./StackedSplineAreaSeriesDescriptionMetadata";
import { Stacked100SplineAreaSeriesDescription } from "./Stacked100SplineAreaSeriesDescription";
/**
 * @hidden
 */
export let Stacked100SplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100SplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100SplineAreaSeriesDescriptionMetadata.a == null) {
                Stacked100SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100SplineAreaSeriesDescriptionMetadata.c(Stacked100SplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(Stacked100SplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedSplineAreaSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100SplineAreaSeriesDescriptionMetadata.b(a);
            a.ac("Stacked100SplineAreaSeries", () => new Stacked100SplineAreaSeriesDescription());
            a.ab("Stacked100SplineAreaSeries", Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
    }
    Stacked100SplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(Stacked100SplineAreaSeriesDescriptionMetadata, 'Stacked100SplineAreaSeriesDescriptionMetadata');
    Stacked100SplineAreaSeriesDescriptionMetadata.a = null;
    return Stacked100SplineAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/Stacked100SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineAreaSeriesDescriptionMetadata } from "./StackedSplineAreaSeriesDescriptionMetadata";
import { Stacked100SplineAreaSeriesDescription } from "./Stacked100SplineAreaSeriesDescription";
/**
 * @hidden
 */
export let Stacked100SplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100SplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100SplineAreaSeriesDescriptionMetadata.a == null) {
                Stacked100SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100SplineAreaSeriesDescriptionMetadata.c(Stacked100SplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(Stacked100SplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedSplineAreaSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100SplineAreaSeriesDescriptionMetadata.b(a);
            a.ae("Stacked100SplineAreaSeries", () => new Stacked100SplineAreaSeriesDescription());
            a.ad("Stacked100SplineAreaSeries", Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
    }
    Stacked100SplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(Stacked100SplineAreaSeriesDescriptionMetadata, 'Stacked100SplineAreaSeriesDescriptionMetadata');
    Stacked100SplineAreaSeriesDescriptionMetadata.a = null;
    return Stacked100SplineAreaSeriesDescriptionMetadata;
})();
